@@ -202,7 +202,13 @@ void SSHManagerPlugin::requestConnection(QSortFilterProxyModel *filterModel,
     auto data = item->data(SSHManagerModel::SSHRole).value<SSHConfigurationData>();
 
     QString sshCommand = QStringLiteral("ssh ");
-    if (!data.useSshConfig) {
+    if (data.useSshConfig) {
+        // useSshConfig is defined in sshwidget.ui:165 -> meaning whether the ssh config is taken from .ssh/config
+        // call that host by data.name (which is the identifier as in sshmanagermodel.cpp:263)
+        sshCommand += data.name;
+    } else {
+        // if (!data.useSshConfig)
+        // useSshConfig is false aka not set, so we just a assume a manual entry in terms of an entry that was added manually to the sshmanager 
         if (data.sshKey.length()) {
             sshCommand += QStringLiteral("-i %1 ").arg(data.sshKey);
         }
@@ -214,10 +220,10 @@ void SSHManagerPlugin::requestConnection(QSortFilterProxyModel *filterModel,
         if (!data.username.isEmpty()) {
             sshCommand += data.username + QLatin1Char('@');
         }
-    }
-
-    if (!data.host.isEmpty()) {
-        sshCommand += data.host;
+        
+        if (!data.host.isEmpty()) {
+            sshCommand += data.host;
+        }
     }
 
     controller->session()->sendTextToTerminal(sshCommand, QLatin1Char('\r'));
